=======
History
=======

0.2.0 (2018-09-10)
------------------

* Better handling for a large variety of error conditions
* Proper fallback mechanism implemented
* Added ``--watch`` option.
* Eliminate unused imports from generated code
* Various bug fixes:
  * Avoid outputting ``.elm`` files with no exports
  * Bugs with HTML attributes and non-string message args
  * Crasher with multi-line messages
  * Crasher when a message is missing from default locale


0.1.0 (2018-07-27)
------------------

* First release on PyPI.
